@@ -1,6 +1,8 @@
 import os
 from enum import Enum
 import yaml
+from mlplatform_lib.utils.dataclass_utils import from_dict
+from mlplatform_lib.dataclass.experiment import ExperimentDataObjectInfo
 
 
 class RunMode(Enum):
@@ -30,6 +32,7 @@ class ApiClient:
         self.proauth_addr = os.environ["proauthAddr"]
         self.experiment_id = os.environ["experimentId"]
         self.train_id = os.environ["trainId"] if "trainId" in os.environ else None
+        self.model_id = os.environ["modelId"] if "modelId" in os.environ else None
         self.inference_id = os.environ["inferenceId"] if "inferenceId" in os.environ else None
         self.serving_id = os.environ["servingId"] if "servingId" in os.environ else None
         self.pvc_mount_path = os.environ["pvcMountPath"]
@@ -47,10 +50,13 @@ class ApiClient:
             self.project_name = server_config["projectName"]
             self.experiment_id = server_config["experimentId"]
             self.train_id = server_config["trainId"]
+            self.model_id = server_config["modelId"]
             self.inference_id = server_config["inferenceId"]
             self.serving_id = server_config["servingId"]
             self.train_do_name = server_config["trainDoName"]
             self.inference_do_name = server_config["inferenceDoName"]
+            self.train_data_object_info_list = [
+                from_dict(ExperimentDataObjectInfo, dict) for dict in server_config["trainDataObjectInfoList"]] if "trainDataObjectInfoList" in server_config else []
         except KeyError as e:
             print(f'Cannot found "{str(e)}" in server_config.yaml')
             exit(1)
