@@ -1,5 +1,6 @@
 from dataclasses import dataclass
-from typing import List, Dict
+from typing import List
+from mlplatform_lib.dataclass import DataObjectOutCol
 
 # example
 # "name": "TEST",
@@ -21,7 +22,7 @@ from typing import List, Dict
 class DataObject:
     id: str
     name: str
-    out_cols: List[Dict[str, str]]
+    out_cols: List[DataObjectOutCol]
     share_relation: List[str]
     source_table_name: str
     subtype: str
