@@ -4,7 +4,7 @@ from dataclasses import dataclass
 @dataclass
 class ExperimentAutomlDto:
     id: int
-    authorization_id: int
+    authentication_id: int
     experiment_type: str
     name: str
     namespace: str
