@@ -1,6 +1,7 @@
 from .inference_dto import InferenceDto
 from .inference_predefinedai_dto import InferencePredefinedaiDto
 from .inference_automl_dto import InferenceAutomlDto
+from .inference_info_dto import InferenceInfoDto
 
 
-__all__ = ["InferenceDto", "InferencePredefinedaiDto", "InferenceAutomlDto"]
+__all__ = ["InferenceDto", "InferencePredefinedaiDto", "InferenceAutomlDto", "InferenceInfoDto"]
