@@ -37,4 +37,4 @@ from typing import List
 @dataclass
 class TableDescInfo:
     col_info_list: List[TableColumnInfo]
-    numRows: int
+    numRows: int = 0
