@@ -254,7 +254,7 @@ class HyperdataHttpClient:
             file_type="csv",
             selector_property=SelectorProperty(
                 column_select_options=[
-                    ColumnOption(name=col_info.name, alias=col_info.alias, type="VARCHAR")
+                    ColumnOption(name=col_info.name, alias=col_info.name, type="VARCHAR")
                     for col_info in table_desc_info.col_info_list
                 ],
                 row_select_options=[],
