@@ -10,7 +10,7 @@ from mlplatform_lib.dataclass import (
 import os
 import pandas as pd
 import sys
-from typing import List, Optional
+from typing import List, Optional, Union
 
 
 class MllabImageType:
@@ -19,10 +19,14 @@ class MllabImageType:
     TORCH = "torch_v1.6.0"
 
 
-if os.environ["image"] == MllabImageType.TENSORFLOW_V1 or os.environ["image"] == MllabImageType.TENSORFLOW_V2:
-    import tensorflow as tf
-elif os.environ["image"] == MllabImageType.TORCH:
-    import torch
+if "image" in os.environ:
+    if (
+        os.environ["image"] == MllabImageType.TENSORFLOW_V1
+        or os.environ["image"] == MllabImageType.TENSORFLOW_V2
+    ):
+        import tensorflow as tf
+    elif os.environ["image"] == MllabImageType.TORCH:
+        import torch
 
 
 class MllabApi:
@@ -32,17 +36,19 @@ class MllabApi:
         self.api_client = api_client
 
         if api_client.run_mode == RunMode.KUBERNETES:
-            self.mllab_mlplatform_client = MllabHttpClient(mlplatform_addr=os.environ["mlplatformAddr"], api_client=api_client)
-            self.mllab_hyperdata_client = HyperdataHttpClient(hd_addr=self.api_client.hyperdata_addr, api_client=self.api_client)
+            self.mllab_mlplatform_client = MllabHttpClient(
+                mlplatform_addr=os.environ["mlplatformAddr"], api_client=api_client
+            )
+            self.mllab_hyperdata_client = HyperdataHttpClient(
+                hd_addr=self.api_client.hyperdata_addr, api_client=self.api_client
+            )
             self.mllab_hyperdata_api = HyperdataApi(api_client=self.api_client)
         self.experiment_id = self.api_client.experiment_id
         self.image = os.environ["image"]
 
     def get_model_list(self) -> Optional[List[ModelDto]]:
         if self.api_client.run_mode == RunMode.KUBERNETES:
-            return self.mllab_mlplatform_client.get_model_list(
-                experiment_id=self.experiment_id
-            )
+            return self.mllab_mlplatform_client.get_model_list(experiment_id=self.experiment_id)
         else:
             print("Current mode is local, Skip get_list_model.")
             return None
@@ -80,34 +86,21 @@ class MllabApi:
             elif self.image == MllabImageType.TENSORFLOW_V2:
                 tf.saved_model.save(model, export_dir, signatures)
             elif self.image == MllabImageType.TORCH:
-                torch.save(model.state_dict(), export_dir + "/model.pt", _use_new_zipfile_serialization=False)
-                if os.path.isfile(self.api_client.pvc_mount_path + "/user_files/user_train.py"):
-                    fin = open(self.api_client.pvc_mount_path + "/user_files/user_train.py", "r")
-                    fout = open(export_dir + "/network_class.py", "w+")
-                    for line in fin:
-                        if line.strip().startswith("import pandas as pd"):
-                            continue
-                        elif line.strip().startswith("import os"):
-                            continue
-                        elif line.strip().startswith("from sklearn.model_selection import train_test_split"):
-                            continue
-                        elif line.strip().startswith(
-                            "from sklearn.metrics import precision_recall_fscore_support"
-                        ):
-                            continue
-                        elif line.strip().startswith("import hyper"):
-                            continue
-                        else:
-                            fout.write(line)
+                jit_saved = torch.jit.script(model)
+                jit_saved.save(export_dir + "/model.pt")
 
             model_dto = self.mllab_mlplatform_client.get_model_by_id(
                 experiment_id=self.experiment_id, train_id=self.api_client.train_id
             )
             model_dto.model_path = export_dir
-            return self.mllab_mlplatform_client.update_model(
+            self.mllab_mlplatform_client.update_model(
+                experiment_id=self.experiment_id, train_id=self.api_client.train_id, dto=model_dto
+            )
+            self.mllab_mlplatform_client.upload_model(
                 experiment_id=self.experiment_id,
                 train_id=self.api_client.train_id,
-                dto=model_dto
+                model_id=model_dto.id,
+                model_path=model_dto.model_path,
             )
         else:
             print("Current mode is local, Skip get_list_do.")
@@ -128,15 +121,12 @@ class MllabApi:
             if os.path.exists(full_path):
                 result = pd.read_csv(full_path, encoding=char_encoding)
                 return result
-           
-            do_path = self.mllab_hyperdata_api.download_csv(
-                do_id=do_id,
-                data_rootpath=dir_name
-            )
 
-            if os.path.exists(do_path) :
+            do_path = self.mllab_hyperdata_api.download_csv(do_id=do_id, data_rootpath=dir_name)
+
+            if os.path.exists(do_path):
                 result = pd.read_csv(do_path, encoding=char_encoding)
-            else :
+            else:
                 print("Fail")
                 result = None
             return result
@@ -146,17 +136,18 @@ class MllabApi:
 
     def get_do_meta(self, do_id: str) -> List[TableColumnInfo]:
         if self.api_client.run_mode == RunMode.KUBERNETES:
-            tableDescInfo = self.mllab_hyperdata_client.get_do_detail_info(
-                do_id=do_id
-            )
+            tableDescInfo = self.mllab_hyperdata_client.get_do_detail_info(do_id=do_id)
             return tableDescInfo.col_info_list
         else:
             print("Current mode is local, Skip get_do_meta.")
             return None
 
-    def save_do(self, input_data: pd.DataFrame, do_id: str, is_truncated: str = False) -> bool:
+    def _get_inference_result_table_name(self, inference_id: int) -> str:
+        mllab_experiment_dto = self.mllab_mlplatform_client.get_experiment(experiment_id=self.experiment_id)
+        return f"MLLAB_{mllab_experiment_dto.name}_{str(mllab_experiment_dto.id)}"
+
+    def save_inference_result(self, input_data: pd.DataFrame, do_id: Optional[str]= None, is_truncated: bool = True) -> bool:
         if self.api_client.run_mode == RunMode.KUBERNETES:
-            print(self.api_client.inference_id)
             if self.api_client.inference_id is not None:
                 file_dir = (
                     self.api_client.pvc_mount_path + "/inference/inference-" + self.api_client.inference_id
@@ -168,15 +159,19 @@ class MllabApi:
             else:
                 print("inference id is None")
                 return False
-
+        
             inference_dto = self.mllab_mlplatform_client.get_inference_by_id(
-                experiment_id=self.experiment_id,
-                inference_id=self.api_client.inference_id
+                experiment_id=self.experiment_id, inference_id=self.api_client.inference_id
             )
             inference_dto.inference_path = file_path
-            self.mllab_mlplatform_client.update_inference(
-                experiment_id=self.experiment_id, dto=inference_dto
-            )
+            self.mllab_mlplatform_client.update_inference(experiment_id=self.experiment_id, dto=inference_dto)
+
+            if(do_id is None):
+                 #create do in default source to save inference result
+                table_name = self._get_inference_result_table_name(inference_dto.id)
+                do_id = self.mllab_hyperdata_api.create_inference_result(
+                    table_name=table_name, object_name=table_name, columns=input_data.columns.tolist()
+                )
 
             insert_tuple_object = InsertTupleObject(
                 isTruncated=is_truncated,
@@ -190,3 +185,9 @@ class MllabApi:
                 return True
             else:
                 return False
+        else:
+            print("Current mode is local, Skip save_inference_result.")
+
+    
+
+        
