@@ -2,6 +2,7 @@ from mlplatform_lib.mlplatform.mlplatform_http_client import (
     MlPlatformHttpClient,
     MlPlatformRequestType,
 )
+from mlplatform_lib.dataclass.experiment import ExperimentMllabDto
 from mlplatform_lib.dataclass.model.model_dto import ModelDto
 from mlplatform_lib.dataclass.inference.inference_dto import InferenceDto
 from mlplatform_lib.utils.dataclass_utils import from_dict, to_dict
@@ -12,6 +13,10 @@ class MllabHttpClient(MlPlatformHttpClient):
     def __init__(self, mlplatform_addr, api_client):
         super().__init__(mlplatform_addr=mlplatform_addr, api_client=api_client)
 
+    def get_experiment(self, experiment_id: int) -> ExperimentMllabDto:
+        result = self.send_request("", {"experiments": experiment_id}, {}, {}, MlPlatformRequestType.READ)
+        return from_dict(ExperimentMllabDto, result.data)
+
     def get_model_list(self, experiment_id: int) -> List[ModelDto]:
         res = self.send_request(
             "models", {"experiments": experiment_id}, {}, {}, MlPlatformRequestType.READ
