@@ -1,6 +1,8 @@
 from mlplatform_lib.api_client import ApiClient
 from mlplatform_lib.hyperdata.hyperdata_http_client import HyperdataHttpClient, HyperdataUserAuth
 from mlplatform_lib.utils.print_utils import print_header
+from mlplatform_lib.dataclass.experiment import ExperimentDataObjectInfo
+from typing import List
 
 
 class MlPlatformLocalChecker:
@@ -14,6 +16,7 @@ class MlPlatformLocalChecker:
 
         # generated
         self.train_do_id = None
+        self.train_data_object_info_list: List[ExperimentDataObjectInfo] = api_client.train_data_object_info_list
         self.inference_do_id = None
 
     """
@@ -49,6 +52,25 @@ class MlPlatformLocalChecker:
         print(f'cannot found train do "{self.train_do_name}".')
         exit(1)
 
+    def _check_train_data_object_list_exist(self):
+        print_header(f'check is train do "{self.train_do_name}" exist.')
+
+        do_list = self.hyperdata_client.get_do_list()
+        for do_info in do_list:
+            for data_object_info in self.train_data_object_info_list:
+                if do_info.name == data_object_info.do_name:
+                    data_object_info.do_id = int(do_info.id)
+
+        not_exist_do_name_list = [data_object_info.do_name for data_object_info in self.train_data_object_info_list
+                                  if data_object_info.do_id is None]
+
+        if len(not_exist_do_name_list) == 0:
+            print("check train data object list end.\n")
+            return
+
+        print(f'cannot found train do "{not_exist_do_name_list}')
+        exit(1)
+
     def _check_inference_do_exist(self):
         print_header(f'check is inference do "{self.inference_do_name}" exist.')
         do_list = self.hyperdata_client.get_do_list()
@@ -64,4 +86,5 @@ class MlPlatformLocalChecker:
 
     def run(self):
         self._check_train_do_exist()
+        self._check_train_data_object_list_exist()
         self._check_inference_do_exist()
